@@ -200,6 +200,8 @@ KQueryOrdersAck = EnumType_pb2.KQueryOrdersAck
 KQueryOrdersReq = EnumType_pb2.KQueryOrdersReq
 KQueryPositionsAck = EnumType_pb2.KQueryPositionsAck
 KQueryPositionsReq = EnumType_pb2.KQueryPositionsReq
+KQueryHisPositionsAck = EnumType_pb2.KQueryHisPositionsAck
+KQueryHisPositionsReq = EnumType_pb2.KQueryHisPositionsReq
 KQueryTradesAck = EnumType_pb2.KQueryTradesAck
 KQueryTradesReq = EnumType_pb2.KQueryTradesReq
 KQuoteMsgID_QuerySecurityInfoReq = Quote_Message_pb2.KQuoteMsgID_QuerySecurityInfoReq
