@@ -71,6 +71,8 @@ Trade_QueryOrdersAck = Trade_Message_pb2.QueryOrdersAck
 Trade_QueryOrdersReq = Trade_Message_pb2.QueryOrdersReq
 Trade_QueryPositionsAck = Trade_Message_pb2.QueryPositionsAck
 Trade_QueryPositionsReq = Trade_Message_pb2.QueryPositionsReq
+Trade_QueryHisPositionsAck = Trade_Message_pb2.QueryHisPositionsAck
+Trade_QueryHisPositionsReq = Trade_Message_pb2.QueryHisPositionsReq
 Trade_QueryTradesAck = Trade_Message_pb2.QueryTradesAck
 Trade_QueryTradesReq = Trade_Message_pb2.QueryTradesReq
 Trade_RegisterAck = Trade_Message_pb2.RegisterAck
