@@ -243,6 +243,13 @@ class TradeApiBase(utils.QujamApiObject):
             cbmsg = structs.ToPyobj(msg)
             self._spi.handle_reply(cbmsg, "onQueryPositions", EnumProto.KQueryPositionsAck)
 
+    @_func_switch("trade_spi", EnumProto.KQueryHisPositionsAck)
+    def _case_query_his_position(self, unit_msg):
+        msg = MsgProto.Trade_QueryHisPositionsAck()
+        if unit_msg.msg_body.Unpack(msg):
+            cbmsg = structs.ToPyobj(msg)
+            self._spi.handle_reply(cbmsg, "onQueryHisPositions", EnumProto.KQueryHisPositionsAck)
+
     @_func_switch("trade_spi", EnumProto.KQueryHistoryOrdersAck)
     def _case_query_history_orders(self, unit_msg):
         msg = MsgProto.Trade_QueryOrdersAck()
@@ -387,6 +394,13 @@ class TradeApiBase(utils.QujamApiObject):
         return self._sync_return(structs.ToProto(req), sync, timeout, EnumProto.KQueryPositionsReq,
                                  EnumProto.KQueryPositionsAck)
 
+    def _query_his_positions(self, req, sync=False, timeout=None):
+        self._verify_connected()
+        self._verify_logined()
+        req.account = self.__user_info.getaccount()
+        return self._sync_return(structs.ToProto(req), sync, timeout, EnumProto.KQueryHisPositionsReq,
+                                 EnumProto.KQueryHisPositionsAck)
+
     def _query_history_orders(self, req, sync=False, timeout=None):
         self._verify_connected()
         self._verify_logined()
