@@ -128,6 +128,11 @@ _pyb.RegisterConvertor(protobuf=MsgProto.Trade_QueryTradesReq).Register(QueryTra
 # QueryPositionsReq
 _pyb.RegisterConvertor(protobuf=MsgProto.Trade_QueryPositionsReq).Register(QueryPositionsReq)
 
+_pyb.RegisterConvertor(
+    _pyb.DatetimeConfigurator(start_time="%Y%m%d-%H:%M:%S.%f", end_time="%Y%m%d-%H:%M:%S.%f"),
+    protobuf=MsgProto.Trade_QueryHisPositionsReq
+).Register(QueryHisPositionsReq)
+
 # QueryHistoryOrdersReq
 _pyb.RegisterConvertor(
     _pyb.DatetimeConfigurator(start_time="%Y%m%d-%H:%M:%S.%f", end_time="%Y%m%d-%H:%M:%S.%f"),
@@ -289,6 +294,11 @@ _pyb.RegisterConvertor(
     protobuf=MsgProto.Trade_QueryPositionsAck,
 ).Register(QueryPositionsAck)
 
+_pyb.RegisterConvertor(
+    _pyb.RepeatConfigurator("positions", recur=True),
+    protobuf=MsgProto.Trade_QueryHisPositionsAck,
+).Register(QueryHisPositionsAck)
+
 # CancelOrderReject
 _pyb.RegisterConvertor(
     _pyb.DatetimeConfigurator(report_time="%Y%m%d-%H:%M:%S.%f"),
